@@ -33,7 +33,6 @@
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
-#include <eel/eel-dnd.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <errno.h>
@@ -55,6 +54,7 @@
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-directory.h>
+#include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-container.h>
@@ -2575,7 +2575,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 	}
 
 	if (action == GDK_ACTION_ASK) {
-		action = eel_drag_drop_action_ask 
+		action = nautilus_drag_drop_action_ask 
 			(GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
 	}
 	
@@ -2739,14 +2739,12 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         klass->set_directory_sort_by = fm_icon_view_real_set_directory_sort_by;
         klass->set_directory_sort_reversed = fm_icon_view_real_set_directory_sort_reversed;
         klass->set_directory_tighter_layout = fm_icon_view_real_set_directory_tighter_layout;
-
-	eel_preferences_add_auto_integer (NAUTILUS_PREFERENCES_PREVIEW_SOUND,
-					       &preview_sound_auto_value);
 }
 
 static void
 fm_icon_view_init (FMIconView *icon_view)
 {
+	static gboolean setup_sound_preview = FALSE;
 	NautilusIconContainer *icon_container;
 
         g_return_if_fail (GTK_BIN (icon_view)->child == NULL);
@@ -2756,6 +2754,12 @@ fm_icon_view_init (FMIconView *icon_view)
 
 	create_icon_container (icon_view);
 
+	if (!setup_sound_preview) {
+		eel_preferences_add_auto_integer (NAUTILUS_PREFERENCES_PREVIEW_SOUND,
+						  &preview_sound_auto_value);
+		setup_sound_preview = TRUE;
+	}
+
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ICON_VIEW_FONT,
 						  font_changed_callback, 
 						  icon_view,
