@@ -32,12 +32,10 @@
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-image.h>
 #include <eel/eel-labeled-image.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <eel/eel-viewport.h>
 #include <eel/eel-wrap-table.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkcheckbutton.h>
@@ -46,6 +44,7 @@
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkhseparator.h>
+#include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtknotebook.h>
@@ -246,24 +245,22 @@ get_pixbuf_for_properties_window (NautilusFile *file)
 {
 	g_assert (NAUTILUS_IS_FILE (file));
 	
-	return nautilus_icon_factory_get_pixbuf_for_file (file, NULL, NAUTILUS_ICON_SIZE_STANDARD, TRUE);
+	return nautilus_icon_factory_get_pixbuf_for_file (file, NULL, NAUTILUS_ICON_SIZE_STANDARD);
 }
 
 static void
-update_properties_window_icon (EelImage *image)
+update_properties_window_icon (GtkImage *image)
 {
 	GdkPixbuf	*pixbuf;
 	NautilusFile	*file;
 
-	g_assert (EEL_IS_IMAGE (image));
-
 	file = g_object_get_data (G_OBJECT (image), "nautilus_file");
 
 	g_assert (NAUTILUS_IS_FILE (file));
 	
 	pixbuf = get_pixbuf_for_properties_window (file);
 
-	eel_image_set_pixbuf (image, pixbuf);
+	gtk_image_set_from_pixbuf (image, pixbuf);
 	
 	g_object_unref (pixbuf);
 }
@@ -299,13 +296,13 @@ fm_properties_window_drag_data_received (GtkWidget *widget, GdkDragContext *cont
 {
 	char **uris;
 	gboolean exactly_one;
-	EelImage *image;
+	GtkImage *image;
  	GtkWindow *window; 
 
 	uris = g_strsplit (selection_data->data, "\r\n", 0);
 	exactly_one = uris[0] != NULL && uris[1] == NULL;
 
-	image = EEL_IMAGE (widget);
+	image = GTK_IMAGE (widget);
  	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (image)));
 
 
@@ -347,7 +344,7 @@ create_image_widget_for_file (NautilusFile *file)
 	
 	pixbuf = get_pixbuf_for_properties_window (file);
 	
-	image = eel_image_new (NULL);
+	image = gtk_image_new ();
 
 	/* prepare the image to receive dropped objects to assign custom images */
 	gtk_drag_dest_set (GTK_WIDGET (image),
@@ -359,7 +356,7 @@ create_image_widget_for_file (NautilusFile *file)
 			    G_CALLBACK (fm_properties_window_drag_data_received), NULL);
 
 
-	eel_image_set_pixbuf (EEL_IMAGE (image), pixbuf);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);
 
 	g_object_unref (pixbuf);
 
@@ -672,7 +669,8 @@ attach_label (GtkTable *table,
 	      const char *initial_text,
 	      gboolean right_aligned,
 	      gboolean bold,
-	      gboolean ellipsize_text)
+	      gboolean ellipsize_text,
+	      gboolean selectable)
 {
 	GtkWidget *label_field;
 
@@ -680,6 +678,10 @@ attach_label (GtkTable *table,
 		? eel_ellipsizing_label_new (initial_text)
 		: gtk_label_new (initial_text);	
 
+	if (selectable) {
+		gtk_label_set_selectable (GTK_LABEL (label_field), TRUE);
+	}
+	
 	if (bold) {
 		eel_gtk_label_make_bold (GTK_LABEL (label_field));
 	}
@@ -703,7 +705,7 @@ attach_value_label (GtkTable *table,
 	      		  int column,
 	      		  const char *initial_text)
 {
-	return attach_label (table, row, column, initial_text, FALSE, FALSE, FALSE);
+	return attach_label (table, row, column, initial_text, FALSE, FALSE, FALSE, TRUE);
 }
 
 static GtkLabel *
@@ -712,7 +714,7 @@ attach_ellipsizing_value_label (GtkTable *table,
 				int column,
 				const char *initial_text)
 {
-	return attach_label (table, row, column, initial_text, FALSE, FALSE, TRUE);
+	return attach_label (table, row, column, initial_text, FALSE, FALSE, TRUE, TRUE);
 }
 
 static void
@@ -1257,7 +1259,7 @@ attach_title_field (GtkTable *table,
 		     int row,
 		     const char *title)
 {
-	return attach_label (table, row, TITLE_COLUMN, title, TRUE, TRUE, FALSE);
+	return attach_label (table, row, TITLE_COLUMN, title, TRUE, TRUE, FALSE, FALSE);
 }		      
 
 static guint
@@ -2330,7 +2332,7 @@ create_properties_window_callback (NautilusFile *file, gpointer callback_data)
 	nautilus_undo_share_undo_manager (GTK_OBJECT (new_window),
 					  GTK_OBJECT (callback_data));
 #endif	
-	eel_gtk_window_present (GTK_WINDOW (new_window));
+	gtk_window_present (GTK_WINDOW (new_window));
 }
 
 static void
@@ -2396,7 +2398,7 @@ fm_properties_window_present (NautilusFile *original_file, FMDirectoryView *dire
 	/* Look to see if there's already a window for this file. */
 	existing_window = g_hash_table_lookup (windows, original_file);
 	if (existing_window != NULL) {
-		eel_gtk_window_present (existing_window);
+		gtk_window_present (existing_window);
 		return;
 	}
 
@@ -2513,17 +2515,15 @@ set_icon_callback (const char* icon_path, FMPropertiesWindow *properties_window)
 static void
 select_image_button_callback (GtkWidget *widget, FMPropertiesWindow *properties_window)
 {
-#if GNOME2_CONVERSION_COMPLETE
 	GtkWidget *dialog;
 
 	g_assert (FM_IS_PROPERTIES_WINDOW (properties_window));
 
 	dialog = eel_gnome_icon_selector_new (_("Select an icon:"),
-						   NULL,
-						   GTK_WINDOW (properties_window),
-						   (EelIconSelectionFunction) set_icon_callback,
-						   properties_window);						   
-#endif
+					      NULL,
+					      GTK_WINDOW (properties_window),
+					      (EelIconSelectionFunction) set_icon_callback,
+					      properties_window);						   
 }
 
 static void
