@@ -28,26 +28,26 @@
 #include <config.h>
 #include "nautilus-complex-search-bar.h"
 
+#include "gtkhwrapbox.h"
 #include "nautilus-search-bar-criterion-private.h"
 #include "nautilus-search-bar-criterion.h"
 #include "nautilus-window-private.h"
+#include <bonobo/bonobo-dock.h>
+#include <eel/eel-gdk-pixbuf-extensions.h>
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glib.h>
 #include <gtk/gtkeventbox.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-dock.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include <libnautilus/nautilus-clipboard.h>
-#include <eel/eel-gdk-pixbuf-extensions.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-string.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
-#include "gtkhwrapbox.h"
+#include <libnautilus/nautilus-clipboard.h>
 
 struct NautilusComplexSearchBarDetails {
 	GtkVBox *bar_container;
@@ -63,39 +63,30 @@ struct NautilusComplexSearchBarDetails {
 	GSList *search_criteria;
 };
 
-static void  real_activate				  (NautilusNavigationBar	       *bar);
-static char *nautilus_complex_search_bar_get_location     (NautilusNavigationBar         *bar);
-static void  nautilus_complex_search_bar_set_location     (NautilusNavigationBar         *bar,
-							   const char                    *location);
-static void  nautilus_complex_search_bar_initialize_class (NautilusComplexSearchBarClass *class);
-static void  nautilus_complex_search_bar_initialize       (NautilusComplexSearchBar      *bar);
-static void  nautilus_complex_search_bar_destroy 	  (GtkObject 			 *object);
-static void  attach_criterion_to_search_bar               (NautilusComplexSearchBar      *bar,
-							   NautilusSearchBarCriterion    *criterion,
-							   int                           position);
+static void       nautilus_complex_search_bar_class_init   (NautilusComplexSearchBarClass *class);
+static void       nautilus_complex_search_bar_init         (NautilusComplexSearchBar      *bar);
+static void       attach_criterion_to_search_bar           (NautilusComplexSearchBar      *bar,
+							    NautilusSearchBarCriterion    *criterion,
+							    int                            position);
+static void       unattach_criterion_from_search_bar       (NautilusComplexSearchBar      *bar,
+							    NautilusSearchBarCriterion    *criterion);
+static void       more_options_callback                    (GtkObject                     *object,
+							    gpointer                       data);
+static void       fewer_options_callback                   (GtkObject                     *object,
+							    gpointer                       data);
+static GtkWidget *load_find_them_pixmap_widget             (void);
+static void       update_options_buttons_state             (NautilusComplexSearchBar      *bar);
+static void       update_find_button_state                 (NautilusComplexSearchBar      *bar);
+static void       update_dynamic_buttons_state             (NautilusComplexSearchBar      *bar);
+static void       update_criteria_choices                  (gpointer                       list_item,
+							    gpointer                       data);
 
-static void  unattach_criterion_from_search_bar           (NautilusComplexSearchBar      *bar,
-							   NautilusSearchBarCriterion    *criterion);
-static void  more_options_callback                        (GtkObject                     *object,
-							   gpointer                       data);
-static void  fewer_options_callback                       (GtkObject                     *object,
-							   gpointer                       data);
-static void  search_bar_criterion_type_changed_callback   (GtkObject *old_criterion_object,
-							   gpointer data);
-static GtkWidget * load_find_them_pixmap_widget           (void);
-
-static void	   update_options_buttons_state 	  (NautilusComplexSearchBar *bar);
-static void	   update_find_button_state 	  	  (NautilusComplexSearchBar *bar);
-static void	   update_dynamic_buttons_state 	  (NautilusComplexSearchBar *bar);
-static void        update_criteria_choices                (gpointer list_item,
-							   gpointer data);
-
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusComplexSearchBar, nautilus_complex_search_bar, NAUTILUS_TYPE_SEARCH_BAR)
+EEL_CLASS_BOILERPLATE (NautilusComplexSearchBar, nautilus_complex_search_bar, NAUTILUS_TYPE_SEARCH_BAR)
 
 /* called by the criterion when the user chooses
    a new criterion type */
 static void 
-search_bar_criterion_type_changed_callback (GtkObject *old_criterion_object,
+search_bar_criterion_type_changed_callback (GObject *old_criterion_object,
 					    gpointer data)
 { 
 	NautilusSearchBarCriterionType new_type;
@@ -110,14 +101,13 @@ search_bar_criterion_type_changed_callback (GtkObject *old_criterion_object,
 	bar = NAUTILUS_COMPLEX_SEARCH_BAR (data);
 
 	/* First create the new criterion with the type that was activated */
-	new_type = GPOINTER_TO_INT (gtk_object_get_data (old_criterion_object,
-							 "type"));
+	new_type = GPOINTER_TO_INT (g_object_get_data (old_criterion_object, "type"));
 	new_criterion = nautilus_search_bar_criterion_new_with_type (new_type, 
 								     bar);
-	gtk_signal_connect (GTK_OBJECT (new_criterion),
+	g_signal_connect (new_criterion,
 			    "criterion_type_changed",
-			    search_bar_criterion_type_changed_callback,
-			    (gpointer) bar);
+			    G_CALLBACK (search_bar_criterion_type_changed_callback),
+			    bar);
 	old_criterion_location = g_slist_find (bar->details->search_criteria,
 					       criterion);
 	old_criterion_location->data = new_criterion;
@@ -167,25 +157,9 @@ queue_search_bar_resize_callback (GtkObject *search_bar,
 		nautilus_complex_search_bar_queue_resize (bar);
 	}
 }
-     
-static void
-nautilus_complex_search_bar_initialize_class (NautilusComplexSearchBarClass *klass)
-{
-	GtkObjectClass *object_class;
-	NautilusNavigationBarClass *navigation_bar_class;
-
-	object_class = GTK_OBJECT_CLASS (klass);
-	object_class->destroy = nautilus_complex_search_bar_destroy;
-
-	navigation_bar_class = NAUTILUS_NAVIGATION_BAR_CLASS (klass);
-	navigation_bar_class->activate = real_activate;
-	navigation_bar_class->get_location = nautilus_complex_search_bar_get_location;
-	navigation_bar_class->set_location = nautilus_complex_search_bar_set_location;
-
-}
 
 static void
-nautilus_complex_search_bar_initialize (NautilusComplexSearchBar *bar)
+nautilus_complex_search_bar_init (NautilusComplexSearchBar *bar)
 {
 	NautilusSearchBarCriterion *file_name_criterion;
 	GtkWidget *hbox;
@@ -205,10 +179,10 @@ nautilus_complex_search_bar_initialize (NautilusComplexSearchBar *bar)
 
 	file_name_criterion = nautilus_search_bar_criterion_first_new (bar);
 
-	gtk_signal_connect (GTK_OBJECT (file_name_criterion),
+	g_signal_connect (file_name_criterion,
 			    "criterion_type_changed",
-			    search_bar_criterion_type_changed_callback,
-			    (gpointer) bar);
+			    G_CALLBACK (search_bar_criterion_type_changed_callback),
+			    bar);
 	bar->details->search_criteria = g_slist_prepend (NULL,
 							 file_name_criterion);
 
@@ -224,14 +198,14 @@ nautilus_complex_search_bar_initialize (NautilusComplexSearchBar *bar)
 
 	hbox = gtk_hwrap_box_new (FALSE);
 
-	gtk_signal_connect (GTK_OBJECT (hbox),
+	g_signal_connect (hbox,
 			    "need_reallocation",
-			    queue_search_bar_resize_callback,
+			    G_CALLBACK (queue_search_bar_resize_callback),
 			    bar);
 
 	bar->details->more_options = gtk_button_new_with_label (_("More Options"));
-	gtk_signal_connect (GTK_OBJECT (bar->details->more_options), "clicked",
-			    more_options_callback, bar);
+	g_signal_connect (bar->details->more_options, "clicked",
+			    G_CALLBACK (more_options_callback), bar);
 				
 				
 	gtk_wrap_box_pack (GTK_WRAP_BOX (hbox),
@@ -240,11 +214,11 @@ nautilus_complex_search_bar_initialize (NautilusComplexSearchBar *bar)
 	gtk_widget_show (bar->details->more_options);
 
 	bar->details->fewer_options = gtk_button_new_with_label (_("Fewer Options"));
-	gtk_signal_connect (GTK_OBJECT (bar->details->fewer_options), "clicked",
-			    fewer_options_callback, bar);
+	g_signal_connect (bar->details->fewer_options, "clicked",
+			    G_CALLBACK (fewer_options_callback), bar);
 
 	gtk_wrap_box_pack (GTK_WRAP_BOX (hbox),
-			    bar->details->fewer_options,
+			   bar->details->fewer_options,
 			   FALSE, FALSE, FALSE, FALSE);
 
 	gtk_widget_show (bar->details->fewer_options);
@@ -266,7 +240,7 @@ nautilus_complex_search_bar_initialize (NautilusComplexSearchBar *bar)
 
 	gtk_container_add (GTK_CONTAINER (bar->details->find_them), find_them_box);
 	gtk_signal_connect_object (GTK_OBJECT (bar->details->find_them), "clicked",
-				   nautilus_navigation_bar_location_changed,
+				   G_CALLBACK (nautilus_navigation_bar_location_changed),
 				   GTK_OBJECT (bar));
 
 	gtk_wrap_box_pack (GTK_WRAP_BOX (hbox), 
@@ -388,12 +362,10 @@ nautilus_complex_search_bar_queue_resize (NautilusComplexSearchBar      *bar)
 	 * shrink when pressing the fewer options button, but it will if the
 	 * window is fairly narrow.
 	 */
-	dock = gtk_widget_get_ancestor (GTK_WIDGET (bar), GNOME_TYPE_DOCK);
+	dock = gtk_widget_get_ancestor (GTK_WIDGET (bar), BONOBO_TYPE_DOCK);
 	if (dock != NULL) {
 		gtk_widget_queue_resize (dock);
 	}
-	
-
 }
 
 static void
@@ -420,14 +392,14 @@ attach_criterion_to_search_bar (NautilusComplexSearchBar *bar,
 		/* We want to track whether the entry text is empty or not. */
 		gtk_signal_connect_object (GTK_OBJECT (criterion->details->value_entry),
 					   "changed", 
-					   update_find_button_state, 
+					   G_CALLBACK (update_find_button_state),
 					   GTK_OBJECT (bar));
 		
 		/* We want to activate the "Find" button when any entry text is not empty */
 		g_assert (GTK_IS_BUTTON (bar->details->find_them));
 		gtk_signal_connect_object (GTK_OBJECT (criterion->details->value_entry), 
 					   "activate",
-					   eel_gtk_button_auto_click, 
+					   G_CALLBACK (gtk_widget_activate),
 					   GTK_OBJECT (bar->details->find_them));
 	}
 	nautilus_complex_search_bar_queue_resize (bar);
@@ -450,24 +422,7 @@ unattach_criterion_from_search_bar (NautilusComplexSearchBar *bar,
 static GtkWidget *
 load_find_them_pixmap_widget (void)
 {
-	GdkPixbuf *pixbuf;
-	GdkPixmap *pixmap;
-	GdkBitmap *mask;
-	GtkWidget *widget;
-	
-	pixbuf = gdk_pixbuf_new_from_file (NAUTILUS_PIXMAPDIR "/search.png");
-	if (pixbuf != NULL) {
-		gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, &mask, EEL_STANDARD_ALPHA_THRESHHOLD);
-		gdk_pixbuf_unref (pixbuf);
-		widget = gtk_pixmap_new (pixmap, mask);
-
-		gdk_pixmap_unref (pixmap);
-		gdk_pixmap_unref (mask);
- 
-		return widget;
-	} else {
-		return NULL;
-	}
+	return gtk_image_new_from_file (NAUTILUS_PIXMAPDIR "/search.png");
 }
 				  
 
@@ -480,7 +435,7 @@ nautilus_complex_search_bar_new (NautilusWindow *window)
 	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), NULL);
 
 	bar = gtk_widget_new (NAUTILUS_TYPE_COMPLEX_SEARCH_BAR, NULL);
-	gtk_object_set_data (GTK_OBJECT (bar), "associated_window", window);
+	g_object_set_data (G_OBJECT (bar), "associated_window", window);
 	
 	/* Set up the first criterion's entry for the clipboard */
 	first_criterion = NAUTILUS_COMPLEX_SEARCH_BAR (bar)->details->search_criteria->data;
@@ -501,7 +456,7 @@ nautilus_complex_search_bar_set_up_enclosed_entry_for_clipboard (NautilusComplex
 {
 	NautilusWindow *associated_window;
 
-	associated_window = gtk_object_get_data (GTK_OBJECT (bar),
+	associated_window = g_object_get_data (G_OBJECT (bar),
 						 "associated_window");
 
 	g_assert (associated_window != NULL);
@@ -527,10 +482,10 @@ more_options_callback (GtkObject *object,
 	last_criterion = (NautilusSearchBarCriterion *)((g_slist_last (list))->data);
 	criterion = nautilus_search_bar_criterion_next_new (last_criterion->details->type,
 							    bar);
-	gtk_signal_connect (GTK_OBJECT (criterion),
+	g_signal_connect (criterion,
 			    "criterion_type_changed",
-			    search_bar_criterion_type_changed_callback,
-			    (gpointer) bar);
+			    G_CALLBACK (search_bar_criterion_type_changed_callback),
+			    bar);
 	bar->details->search_criteria = g_slist_append (list, criterion);
 
 	nautilus_search_bar_criterion_show (criterion);
@@ -647,3 +602,19 @@ nautilus_complex_search_bar_get_search_criteria (NautilusComplexSearchBar *bar)
 {
 	return bar->details->search_criteria;
 }
+
+static void
+nautilus_complex_search_bar_class_init (NautilusComplexSearchBarClass *klass)
+{
+	GtkObjectClass *object_class;
+	NautilusNavigationBarClass *navigation_bar_class;
+
+	object_class = GTK_OBJECT_CLASS (klass);
+	object_class->destroy = nautilus_complex_search_bar_destroy;
+
+	navigation_bar_class = NAUTILUS_NAVIGATION_BAR_CLASS (klass);
+	navigation_bar_class->activate = real_activate;
+	navigation_bar_class->get_location = nautilus_complex_search_bar_get_location;
+	navigation_bar_class->set_location = nautilus_complex_search_bar_set_location;
+
+}
