@@ -40,12 +40,10 @@
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-image-table.h>
-#include <eel/eel-image.h>
 #include <eel/eel-labeled-image.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <eel/eel-viewport.h>
 #include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
@@ -277,8 +275,7 @@ nautilus_property_browser_init (GtkObject *object)
 	gtk_container_set_border_width (GTK_CONTAINER (property_browser->details->category_container), 0);
  	property_browser->details->category_position = -1;	
  	
- 	viewport = eel_viewport_new (NULL, NULL);	
-	eel_viewport_set_never_smooth (EEL_VIEWPORT (viewport), FALSE);
+ 	viewport = gtk_viewport_new (NULL, NULL);	
 	gtk_widget_show (viewport);
 	gtk_viewport_set_shadow_type(GTK_VIEWPORT(viewport), GTK_SHADOW_NONE);
 
@@ -487,7 +484,7 @@ nautilus_property_browser_show (void)
 	if (main_browser == NULL) {
 		main_browser = nautilus_property_browser_new ();
 	} else {
-		eel_gtk_window_present (GTK_WINDOW (main_browser));
+		gtk_window_present (GTK_WINDOW (main_browser));
 	}
 }
 
@@ -958,11 +955,9 @@ nautilus_emblem_dialog_new (NautilusPropertyBrowser *property_browser)
 	gtk_entry_set_text(GTK_ENTRY(entry), property_browser->details->image_path);
 	
 	/* install the table in the dialog */	
-	gtk_widget_show(table);	
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), table, TRUE, TRUE, GNOME_PAD);
-#if GNOME2_CONVERSION_COMPLETE
-	gtk_dialog_set_default(GTK_DIALOG(dialog), GNOME_OK);
-#endif
+	gtk_widget_show (table);	
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, TRUE, TRUE, GNOME_PAD);
+	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 	gtk_window_set_wmclass(GTK_WINDOW(dialog), "emblem_dialog", "Nautilus");
 	
 	return dialog;
@@ -1008,17 +1003,13 @@ nautilus_color_selection_dialog_new (NautilusPropertyBrowser *property_browser)
 		
 	/* install the table in the dialog */
 	
-	gtk_widget_show(table);	
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), table, TRUE, TRUE, GNOME_PAD);
-#if GNOME2_CONVERSION_COMPLETE
-	gtk_dialog_set_default(GTK_DIALOG(dialog), GNOME_OK);
-#endif
+	gtk_widget_show (table);	
+	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), table, TRUE, TRUE, GNOME_PAD);
+	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 	
 	return dialog;
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 /* add the newly selected file to the browser images */
 static void
 add_pattern_to_browser (const char *path_name, gpointer *data)
@@ -1092,8 +1083,6 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	nautilus_property_browser_update_contents (property_browser);
 }
 
-#endif
-
 /* here's where we initiate adding a new pattern by putting up a file selector */
 
 static void
@@ -1105,7 +1094,6 @@ add_new_pattern (NautilusPropertyBrowser *property_browser)
 			gdk_window_raise(property_browser->details->dialog->window);
 		}
 	} else {
-#if GNOME2_CONVERSION_COMPLETE
 		property_browser->details->dialog = 
 			eel_gnome_icon_selector_new (_("Select an image file to add as a pattern:"),
 				DATADIR "/pixmaps/tiles/",
@@ -1114,7 +1102,6 @@ add_new_pattern (NautilusPropertyBrowser *property_browser)
 				property_browser);						   
 
 		eel_nullify_when_destroyed (&property_browser->details->dialog);
-#endif
 	}
 }
 
@@ -1478,7 +1465,7 @@ element_clicked_callback (GtkWidget *image_table,
 	GdkPixbuf *pixbuf;
 	int x_delta, y_delta;
 	const char *element_name;
-	EelArtIPoint scroll_offset;
+	int scroll_offset_x, scroll_offset_y;
 
 	g_return_if_fail (EEL_IS_IMAGE_TABLE (image_table));
 	g_return_if_fail (EEL_IS_LABELED_IMAGE (child));
@@ -1516,10 +1503,8 @@ element_clicked_callback (GtkWidget *image_table,
 				  NULL);
 
 	/* compute the offsets for dragging */
-	scroll_offset = eel_viewport_get_scroll_offset (EEL_VIEWPORT (image_table->parent));
-
 	if (strcmp (drag_types[0].target, "application/x-color")) {
-		/*it's not a color, so, for now, it must be an image */
+		/* it's not a color, so, for now, it must be an image */
 		/* fiddle with the category to handle the "reset" case properly */
 		char * save_category = property_browser->details->category;
 		if (eel_strcmp (property_browser->details->category, "colors") == 0) {
@@ -1531,8 +1516,11 @@ element_clicked_callback (GtkWidget *image_table,
 		y_delta = gdk_pixbuf_get_height (pixbuf) / 2;
 	} else {
 		pixbuf = make_color_drag_image (property_browser, element_name, TRUE);
-		x_delta = event->x - child->allocation.x - scroll_offset.x;
-		y_delta = event->y - child->allocation.y - scroll_offset.y;
+		gdk_window_get_position (GTK_VIEWPORT (image_table->parent)->bin_window,
+					 &scroll_offset_x,
+					 &scroll_offset_y);
+		x_delta = event->x - child->allocation.x - scroll_offset_x;
+		y_delta = event->y - child->allocation.y - scroll_offset_y;
 	}
 
         /* set the pixmap and mask for dragging */       
@@ -1580,13 +1568,7 @@ labeled_image_configure (EelLabeledImage *labeled_image)
 {
 	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
 
-#if GNOME2_CONVERSION_COMPLETE
-	eel_labeled_image_set_background_mode (labeled_image,
-					       EEL_SMOOTH_BACKGROUND_SOLID_COLOR);
-	eel_labeled_image_set_solid_background_color (labeled_image,
-						      EEL_RGB_COLOR_WHITE);		
 	eel_labeled_image_set_spacing (labeled_image, LABELED_IMAGE_SPACING);
-#endif
 }
 
 /* Make a color tile for a property */
@@ -1600,12 +1582,6 @@ labeled_image_new (const char *text,
 	
 	labeled_image = eel_labeled_image_new (text, pixbuf);
 	labeled_image_configure (EEL_LABELED_IMAGE (labeled_image));
-#if GNOME2_CONVERSION_COMPLETE
-	if (num_smaller > 0) {
-		eel_labeled_image_make_smaller (EEL_LABELED_IMAGE (labeled_image),
-						     num_smaller);
-	}
-#endif
 
 	if (property_name != NULL) {
 		g_object_set_data_full (G_OBJECT (labeled_image),
@@ -1855,13 +1831,7 @@ property_browser_category_button_new (const char *display_name,
 	file_name = nautilus_pixmap_file (image); 
 	g_return_val_if_fail (file_name != NULL, NULL);
 
-	button = eel_labeled_image_toggle_button_new_from_file_name (display_name,
-									  file_name);
-
-#if GNOME2_CONVERSION_COMPLETE
-	/* We want the label to never be smooth */
-	eel_labeled_image_set_label_never_smooth (EEL_LABELED_IMAGE (GTK_BIN (button)->child), TRUE);
-#endif
+	button = eel_labeled_image_toggle_button_new_from_file_name (display_name, file_name);
 
 	/* We also want all of the buttons to be the same height */
 	eel_labeled_image_set_fixed_image_height (EEL_LABELED_IMAGE (GTK_BIN (button)->child), STANDARD_BUTTON_IMAGE_HEIGHT);
@@ -1940,8 +1910,7 @@ nautilus_property_browser_update_contents (NautilusPropertyBrowser *property_bro
 	/* allocate a new container, with a scrollwindow and viewport */
 	property_browser->details->content_frame = gtk_scrolled_window_new (NULL, NULL);
 	gtk_container_set_border_width (GTK_CONTAINER (property_browser->details->content_frame), 0);				
- 	viewport = eel_viewport_new (NULL, NULL);
-	eel_viewport_set_never_smooth (EEL_VIEWPORT (viewport), FALSE);
+ 	viewport = gtk_viewport_new (NULL, NULL);
 	gtk_widget_show(viewport);
 	gtk_viewport_set_shadow_type(GTK_VIEWPORT(viewport), GTK_SHADOW_IN);
 	background = eel_get_widget_background (viewport);
