@@ -27,23 +27,21 @@
 #include "nautilus-view-frame.h"
 
 #include <bonobo/bonobo-event-source.h>
+#include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-listener.h>
 #include <bonobo/bonobo-property-bag-client.h>
 #include <bonobo/bonobo-ui-util.h>
-#include <bonobo/bonobo-exception.h>
-
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libgnome/gnome-defs.h>
-#include <libgnome/gnome-util.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
-#include <libnautilus-private/nautilus-global-preferences.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-scalable-font.h>
 #include <eel/eel-string.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtkselection.h>
+#include <libgnome/gnome-util.h>
+#include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-theme.h>
 #include <math.h>
 #include <stdio.h>
@@ -73,9 +71,6 @@
 #define TAB_ACTIVE_PRELIGHT_RIGHT 	18
 #define LAST_TAB_OFFSET			19
 
-/* FIXME: Hard coded font size */
-#define DEFAULT_FONT_SIZE 12
-
 #define RIGHT_MARGIN_WIDTH 12
 
 /* data structures */
@@ -87,7 +82,7 @@ typedef struct {
 	char *indicator_pixbuf_name;
 	GdkPixbuf *indicator_pixbuf;
 	int notebook_page;
-	Bonobo_EventSource_ListenerId listener_id;
+	Bonobo_Listener listener;
 	GtkWidget *tab_view;
 	GdkRectangle tab_rect;
 } TabItem;
@@ -97,8 +92,6 @@ struct NautilusSidebarTabsDetails {
 	int total_height;
 	gboolean title_mode;
 	GdkRectangle title_rect;
-	EelScalableFont *tab_font;	
-	int font_size;
 	GdkColor tab_color;
 	GdkColor background_color;
 	GdkColor line_color;
@@ -127,8 +120,8 @@ struct NautilusSidebarTabsDetails {
 
 /* headers */
 
-static void     nautilus_sidebar_tabs_initialize_class  (NautilusSidebarTabsClass *klass);
-static void     nautilus_sidebar_tabs_initialize        (NautilusSidebarTabs      *pixmap);
+static void     nautilus_sidebar_tabs_class_init  (NautilusSidebarTabsClass *klass);
+static void     nautilus_sidebar_tabs_init        (NautilusSidebarTabs      *pixmap);
 static int      nautilus_sidebar_tabs_expose            (GtkWidget                *widget,
 							 GdkEventExpose           *event);
 static void     nautilus_sidebar_tabs_destroy           (GtkObject                *object);
@@ -141,12 +134,11 @@ static void     draw_or_layout_all_tabs                 (NautilusSidebarTabs
 							 gboolean                  layout_only);
 static TabItem* tab_item_find_by_name                   (NautilusSidebarTabs      *sidebar_tabs,
 							 const char               *name);
-static void     smooth_font_changed_callback            (gpointer                  callback_data);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusSidebarTabs, nautilus_sidebar_tabs, GTK_TYPE_WIDGET)
+EEL_CLASS_BOILERPLATE (NautilusSidebarTabs, nautilus_sidebar_tabs, GTK_TYPE_WIDGET)
 
 static void
-nautilus_sidebar_tabs_initialize_class (NautilusSidebarTabsClass *class)
+nautilus_sidebar_tabs_class_init (NautilusSidebarTabsClass *class)
 {
 	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
@@ -163,7 +155,7 @@ nautilus_sidebar_tabs_initialize_class (NautilusSidebarTabsClass *class)
 static void
 setup_light_text(NautilusSidebarTabs *sidebar_tabs)
 {
-	gdk_color_parse ("rgb:ff/ff/ff", &sidebar_tabs->details->text_color);
+	gdk_color_parse ("#ffffff", &sidebar_tabs->details->text_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->text_color, FALSE, TRUE);
 }
@@ -171,7 +163,7 @@ setup_light_text(NautilusSidebarTabs *sidebar_tabs)
 static void
 setup_dark_text(NautilusSidebarTabs *sidebar_tabs)
 {
-	gdk_color_parse ("rgb:00/00/00", &sidebar_tabs->details->text_color);
+	gdk_color_parse ("#000000", &sidebar_tabs->details->text_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->text_color, FALSE, TRUE);
 }
@@ -182,7 +174,7 @@ nautilus_sidebar_tabs_load_theme_data (NautilusSidebarTabs *sidebar_tabs)
 {
 	char *temp_str;
 	char *tab_pieces, *tab_piece_path, *tab_piece_theme;
-	GdkColor color;
+	guint32 color;
 	int intensity;
 	
 	/* set up the default values */
@@ -226,9 +218,11 @@ nautilus_sidebar_tabs_load_theme_data (NautilusSidebarTabs *sidebar_tabs)
 				sidebar_tabs->details->tab_height = gdk_pixbuf_get_height (sidebar_tabs->details->tab_piece_images[0]);
 				
 				/* set the text color according to the pixbuf */
-				eel_gdk_pixbuf_average_value (sidebar_tabs->details->tab_piece_images[TAB_NORMAL_FILL], &color);
-				intensity = (((color.red >> 8) * 77) + ((color.green >> 8) * 150) + ((color.blue >> 8) * 28)) >> 8;	
-
+				color = eel_gdk_pixbuf_average_value (sidebar_tabs->details->tab_piece_images[TAB_NORMAL_FILL]);
+				intensity = ((EEL_RGBA_COLOR_GET_R (color) >> 8) * 77
+					     + (EEL_RGBA_COLOR_GET_G (color) >> 8) * 150
+					     + (EEL_RGBA_COLOR_GET_B (color) >> 8) * 28) >> 8;
+				
 				if (intensity < 160) {
 					setup_light_text (sidebar_tabs);
 				} else {
@@ -238,9 +232,10 @@ nautilus_sidebar_tabs_load_theme_data (NautilusSidebarTabs *sidebar_tabs)
 		}	
 	}	
 
+#if GNOME2_CONVERSION_COMPLETE
 	/* unload the old font if necessary */
 	if (sidebar_tabs->details->tab_font != NULL) {
-		gtk_object_unref (GTK_OBJECT (sidebar_tabs->details->tab_font));
+		g_object_unref (sidebar_tabs->details->tab_font);
 		sidebar_tabs->details->tab_font = NULL;
 	}
 
@@ -248,8 +243,11 @@ nautilus_sidebar_tabs_load_theme_data (NautilusSidebarTabs *sidebar_tabs)
 
 	/* FIXME: Hard coded font size */
 	sidebar_tabs->details->font_size = DEFAULT_FONT_SIZE;
+#endif
 }
 
+#if GNOME2_CONVERSION_COMPLETE
+
 /* Use the font from preferences */
 static void
 smooth_font_changed_callback (gpointer callback_data)
@@ -263,7 +261,7 @@ smooth_font_changed_callback (gpointer callback_data)
 	new_font = nautilus_global_preferences_get_default_smooth_bold_font ();
 
 	if (sidebar_tabs->details->tab_font != NULL) {
-		gtk_object_unref (GTK_OBJECT (sidebar_tabs->details->tab_font));
+		g_object_unref (sidebar_tabs->details->tab_font);
 		sidebar_tabs->details->tab_font = NULL;
 	}
 
@@ -272,32 +270,34 @@ smooth_font_changed_callback (gpointer callback_data)
 	gtk_widget_queue_resize (GTK_WIDGET (sidebar_tabs));
 }
 
+#endif
+
 /* initialize a newly allocated sidebar tabs object */
 static void
-nautilus_sidebar_tabs_initialize (NautilusSidebarTabs *sidebar_tabs)
+nautilus_sidebar_tabs_init (NautilusSidebarTabs *sidebar_tabs)
 {
 	GTK_WIDGET_SET_FLAGS (GTK_WIDGET(sidebar_tabs), GTK_NO_WINDOW);
 	
 	sidebar_tabs->details = g_new0 (NautilusSidebarTabsDetails, 1);
 		
 	/* set up the default colors used for the structured (non-themed) tabs */
-	gdk_color_parse ("rgb:99/99/99", &sidebar_tabs->details->tab_color);
+	gdk_color_parse ("#999999", &sidebar_tabs->details->tab_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->tab_color, FALSE, TRUE);
 	
-	gdk_color_parse ("rgb:ee/ee/ee", &sidebar_tabs->details->prelight_color);
+	gdk_color_parse ("#eeeeee", &sidebar_tabs->details->prelight_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->prelight_color, FALSE, TRUE);
 	
-	gdk_color_parse ("rgb:ff/ff/ff", &sidebar_tabs->details->background_color);
+	gdk_color_parse ("#ffffff", &sidebar_tabs->details->background_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->background_color, FALSE, TRUE);
 	
-	gdk_color_parse ("rgb:00/00/00", &sidebar_tabs->details->line_color);
+	gdk_color_parse ("#000000", &sidebar_tabs->details->line_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->line_color, FALSE, TRUE);
 	
-	gdk_color_parse ("rgb:d6/d6/d6", &sidebar_tabs->details->hilight_color);
+	gdk_color_parse ("#d6d6d6", &sidebar_tabs->details->hilight_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->hilight_color, FALSE, TRUE);
 	
@@ -308,9 +308,11 @@ nautilus_sidebar_tabs_initialize (NautilusSidebarTabs *sidebar_tabs)
 	eel_preferences_add_callback(NAUTILUS_PREFERENCES_THEME, 
 				     (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
 				     sidebar_tabs);
+#if GNOME2_CONVERSION_COMPLETE
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
 				      smooth_font_changed_callback,
 				      sidebar_tabs);
+#endif
 	
 	sidebar_tabs->details->title_prelit = FALSE;
 }
@@ -347,22 +349,27 @@ static void
 tab_item_destroy (TabItem *item)
 {
 	Bonobo_PropertyBag property_bag;
-	
+	CORBA_Environment ev;
+
 	g_free (item->tab_text);
 	g_free (item->indicator_pixbuf_name);
 	
 	if (item->indicator_pixbuf != NULL) {
-		gdk_pixbuf_unref (item->indicator_pixbuf);
+		g_object_unref (item->indicator_pixbuf);
 	}
 
-	if (item->listener_id != 0) {
+	if (item->listener != CORBA_OBJECT_NIL) {
 		property_bag = get_property_bag (item);
-		if (property_bag != CORBA_OBJECT_NIL) {	
+		if (property_bag != CORBA_OBJECT_NIL) {
 			bonobo_event_source_client_remove_listener
-				(property_bag, item->listener_id, NULL);
+				(property_bag, item->listener, NULL);
 			bonobo_object_release_unref (property_bag, NULL);
 		}
+		CORBA_exception_init (&ev);
+		CORBA_Object_release (item->listener, &ev);
+		CORBA_exception_free (&ev);
 	}
+
 	g_free (item);
 }
 
@@ -376,31 +383,37 @@ tab_item_destroy_cover (gpointer item, gpointer callback_data)
 static void
 nautilus_sidebar_tabs_destroy (GtkObject *object)
 {
-	NautilusSidebarTabs *sidebar_tabs = NAUTILUS_SIDEBAR_TABS(object);
-   	
-	/* deallocate the tab piece images, if any */
-	if (sidebar_tabs->details->tab_piece_images[0] != NULL) {
-		nautilus_sidebar_tabs_unload_tab_pieces (sidebar_tabs);
+	GList *tab_items;
+	NautilusSidebarTabs *sidebar_tabs = NAUTILUS_SIDEBAR_TABS (object);
+
+   	if (sidebar_tabs->details) {
+		/* deallocate the tab piece images, if any */
+		if (sidebar_tabs->details->tab_piece_images[0] != NULL) {
+			nautilus_sidebar_tabs_unload_tab_pieces (sidebar_tabs);
+		}
+	
+		/* release the tab list, if any */
+		if (sidebar_tabs->details->tab_items) {
+			tab_items = sidebar_tabs->details->tab_items;
+			sidebar_tabs->details->tab_items = NULL;
+
+			eel_g_list_free_deep_custom (tab_items,
+						     tab_item_destroy_cover,
+						     NULL);
+		}
+	
+		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME, 
+						 (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
+						 sidebar_tabs);
+#if GNOME2_CONVERSION_COMPLETE
+		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
+						 smooth_font_changed_callback,
+						 sidebar_tabs);
+#endif
+	
+		g_free (sidebar_tabs->details);
+		sidebar_tabs->details = NULL;
 	}
-	
-	if (sidebar_tabs->details->tab_font != NULL) {
-		gtk_object_unref (GTK_OBJECT (sidebar_tabs->details->tab_font));
-		sidebar_tabs->details->tab_font = NULL;
-	}
-	
-	/* release the tab list, if any */
-	eel_g_list_free_deep_custom (sidebar_tabs->details->tab_items,
-				     tab_item_destroy_cover,
-				     NULL);
-	
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME, 
-					 (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
-					 sidebar_tabs);
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
-					 smooth_font_changed_callback,
-					 sidebar_tabs);
-	
-	g_free (sidebar_tabs->details);
   	
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
@@ -412,7 +425,7 @@ nautilus_sidebar_tabs_unload_tab_pieces (NautilusSidebarTabs *sidebar_tabs)
 	int index;
 	for (index = 0; index < LAST_TAB_OFFSET; index++) {
 		if (sidebar_tabs->details->tab_piece_images[index]) {
-			gdk_pixbuf_unref (sidebar_tabs->details->tab_piece_images[index]);
+			g_object_unref (sidebar_tabs->details->tab_piece_images[index]);
 			sidebar_tabs->details->tab_piece_images[index] = NULL;			
 		}
 	}	
@@ -426,7 +439,7 @@ load_tab_piece (const char *piece_directory, const char *piece_name)
 	GdkPixbuf *pixbuf;
 	gchar *image_path;
 	image_path = g_strdup_printf ("%s/%s.png", piece_directory, piece_name);	
-	pixbuf = gdk_pixbuf_new_from_file (image_path);
+	pixbuf = gdk_pixbuf_new_from_file (image_path, NULL);
 	if (pixbuf == NULL) {
 		g_warning ("cant load tab piece: %s", image_path);
 	}
@@ -592,11 +605,12 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 	int tab_bottom;
 	int tab_right;
 	int indicator_width;
-	EelDimensions name_dimensions;
+	PangoLayout *layout;
 	int total_width;
 	GtkWidget *widget;
 	GdkPixbuf *temp_pixbuf;
 	GdkColor *foreground_color;
+	int text_width, text_height;
 	
 	g_assert (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs));
 
@@ -606,13 +620,12 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 		indicator_width = 0;
 	}
 
-	/* measure the name and compute the bounding box */
-	name_dimensions = eel_scalable_font_measure_text (sidebar_tabs->details->tab_font, 
-							  sidebar_tabs->details->font_size,
-							  tab_name,
-							  strlen (tab_name));
-	
-	total_width = name_dimensions.width + indicator_width + 2 * TAB_MARGIN;
+	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
+	pango_layout_set_text (layout, tab_name, -1);
+
+	pango_layout_get_pixel_size (layout, &text_width, &text_height);
+
+	total_width = text_width + indicator_width + 2 * TAB_MARGIN;
 
 	widget = GTK_WIDGET (sidebar_tabs);
 	
@@ -647,7 +660,8 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 	gdk_draw_line(widget->window, gc, x + 2, y + 2, x + 2, y + sidebar_tabs->details->tab_height - 1);
 	
 	/* allocate the pixbuf and fill it with the background color */
-	temp_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, name_dimensions.width + indicator_width + 1, name_dimensions.height + 1);
+	temp_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
+				      text_width + indicator_width + 1, text_height + 1);
 	eel_gdk_pixbuf_fill_rectangle_with_color (temp_pixbuf,
 						  eel_gdk_pixbuf_whole_pixbuf,
 						  eel_gdk_color_to_rgb (foreground_color));
@@ -658,21 +672,13 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 	}
 	
 	/* draw the name into the pixbuf using anti-aliased text */
-	eel_scalable_font_draw_text (sidebar_tabs->details->tab_font, temp_pixbuf, 
-				     1 + indicator_width, 1, 
-				     eel_gdk_pixbuf_whole_pixbuf,
-				     sidebar_tabs->details->font_size,
-				     tab_name, strlen (tab_name),
-				     prelight_flag ? EEL_RGB_COLOR_WHITE : EEL_RGB_COLOR_BLACK,
-				     EEL_OPACITY_FULLY_OPAQUE);
+	eel_gdk_pixbuf_draw_layout (temp_pixbuf, 1 + indicator_width, 1,
+				    prelight_flag ? EEL_RGB_COLOR_WHITE : EEL_RGB_COLOR_BLACK,
+				    layout);
 	
-	eel_scalable_font_draw_text (sidebar_tabs->details->tab_font, temp_pixbuf, 
-				     indicator_width, 0,
-				     eel_gdk_pixbuf_whole_pixbuf,
-				     sidebar_tabs->details->font_size,
-				     tab_name, strlen (tab_name),
-				     prelight_flag ? EEL_RGB_COLOR_BLACK : EEL_RGB_COLOR_WHITE,
-				     EEL_OPACITY_FULLY_OPAQUE);
+	eel_gdk_pixbuf_draw_layout (temp_pixbuf, indicator_width, 0,
+				    prelight_flag ? EEL_RGB_COLOR_BLACK : EEL_RGB_COLOR_WHITE,
+				    layout);
 	
 	/* blit the pixbuf to the drawable, then release it */
 
@@ -680,22 +686,24 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 					     widget->window,
 					     0, 0,
 					     x + TAB_MARGIN, y + 5,
-					     name_dimensions.width + indicator_width + 1, name_dimensions.height + 1,
+					     text_width + indicator_width + 1, text_height + 1,
 					     GDK_PIXBUF_ALPHA_BILEVEL, 128,
 					     GDK_RGB_DITHER_MAX,
 					     0, 0);
 	
-	gdk_pixbuf_unref (temp_pixbuf);	
+	g_object_unref (temp_pixbuf);	
 	
 	/* draw the bottom lines */
 	tab_bottom = y + sidebar_tabs->details->tab_height - 1;
 	gdk_gc_set_foreground (gc, &sidebar_tabs->details->line_color);  
-	tab_right = x + 2*TAB_MARGIN + name_dimensions.width + indicator_width;
+	tab_right = x + 2*TAB_MARGIN + text_width + indicator_width;
 	gdk_gc_set_foreground (gc, &sidebar_tabs->details->line_color);  
 	gdk_draw_line(widget->window, gc, tab_right, tab_bottom, widget->parent->allocation.width, tab_bottom);
 	gdk_draw_line(widget->window, gc, 0, tab_bottom, x, tab_bottom);
+
+	g_object_unref (layout);
 	
-	return name_dimensions.width + indicator_width + 2 * TAB_MARGIN;
+	return text_width + indicator_width + 2 * TAB_MARGIN;
 }
 
 /* utility to draw a single tab piece into a pixbuf */
@@ -763,14 +771,14 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 		     GdkRectangle *tab_rect)
 {  
 	GtkWidget *widget;
-	EelDimensions name_dimensions;
-	int piece_width, tab_width;
+	int piece_width, text_width;
 	int current_pos, right_edge_pos;
 	int text_x_pos, left_width;
 	int highlight_offset;
 	int text_x;
 	int text_y;
 	int indicator_width;
+	PangoLayout *layout;
 	
 	if (indicator_pixbuf != NULL) {
 		indicator_width = gdk_pixbuf_get_width (indicator_pixbuf);
@@ -790,10 +798,11 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 	}
 	
 	/* measure the size of the name */
-	name_dimensions = eel_scalable_font_measure_text (sidebar_tabs->details->tab_font,
-							  sidebar_tabs->details->font_size,
-							  tab_name,
-							  strlen (tab_name));
+	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
+	pango_layout_set_text (layout, tab_name, -1);
+
+	pango_layout_get_pixel_size (layout, &text_width, NULL);
+
 	/* draw the left edge piece */
 	current_pos = x - widget->allocation.x;
 	if (first_flag) {
@@ -804,7 +813,7 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 	
 	/* draw the middle portion in a loop */	
 	text_x_pos = current_pos;
-	right_edge_pos = current_pos + name_dimensions.width + indicator_width;
+	right_edge_pos = current_pos + text_width + indicator_width;
 	while (current_pos < right_edge_pos) {
 		piece_width = draw_tab_piece_aa (sidebar_tabs, tab_pixbuf, current_pos, y - widget->allocation.y, 
 						 right_edge_pos, TAB_NORMAL_FILL + highlight_offset);
@@ -821,29 +830,19 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 	/* make sure we can at least draw some of it */
 	if (text_x < gdk_pixbuf_get_width (tab_pixbuf)) {	
 		if (indicator_pixbuf) {
-			
 			pixbuf_composite (indicator_pixbuf, tab_pixbuf, text_x, text_y, 255);
 			text_x += indicator_width;
 		} 
 
-		eel_scalable_font_draw_text (sidebar_tabs->details->tab_font, tab_pixbuf, 
-					     text_x, text_y,
-					     eel_gdk_pixbuf_whole_pixbuf,
-					     sidebar_tabs->details->font_size,
-					     tab_name, strlen (tab_name),
-					     EEL_RGB_COLOR_BLACK,
-					     EEL_OPACITY_FULLY_OPAQUE);
-		text_x -= 1;
-		text_y -= 1;
-
-		eel_scalable_font_draw_text (sidebar_tabs->details->tab_font, tab_pixbuf,
-					     text_x, text_y,
-					     eel_gdk_pixbuf_whole_pixbuf,
-					     sidebar_tabs->details->font_size,
-					     tab_name, strlen (tab_name),
-					     EEL_RGB_COLOR_WHITE,
-					     EEL_OPACITY_FULLY_OPAQUE);
+		eel_gdk_pixbuf_draw_layout (tab_pixbuf, text_x, text_y,
+					    EEL_RGB_COLOR_BLACK,
+					    layout);
+		eel_gdk_pixbuf_draw_layout (tab_pixbuf, text_x - 1, text_y - 1,
+					    EEL_RGB_COLOR_WHITE,
+					    layout);
 	}
+
+	g_object_unref (layout);
 	
 	/* set up the bounds rectangle for later hit-testing */
 	if (tab_rect) {
@@ -854,8 +853,7 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 	}
 	
 	/* return the total tab width */
-	tab_width = left_width + name_dimensions.width + indicator_width;
-	return tab_width;	
+	return left_width + text_width + indicator_width;
 }
 
 static int
@@ -879,8 +877,8 @@ get_text_offset (void)
 static int
 get_tab_width (NautilusSidebarTabs *sidebar_tabs, TabItem *this_tab, gboolean is_themed, gboolean first_flag)
 {
-	int edge_width, indicator_width;
-	EelDimensions name_dimensions;
+	PangoLayout *layout;
+	int text_width, edge_width, indicator_width;
 	
 	if (this_tab == NULL)
 		return 0;
@@ -897,17 +895,15 @@ get_tab_width (NautilusSidebarTabs *sidebar_tabs, TabItem *this_tab, gboolean is
 		} else {
 			edge_width = 0;
 		}
-
-		name_dimensions = eel_scalable_font_measure_text (sidebar_tabs->details->tab_font,
-								  sidebar_tabs->details->font_size,
-								  this_tab->tab_text,
-								  strlen (this_tab->tab_text));
-	
 	} else {	
 		edge_width = 2 * TAB_MARGIN;
-		name_dimensions.width = gdk_string_width (GTK_WIDGET (sidebar_tabs)->style->font, this_tab->tab_text);
-	}		
-	return name_dimensions.width + edge_width + indicator_width;
+	}
+	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
+	pango_layout_set_text (layout, this_tab->tab_text, -1);
+	pango_layout_get_pixel_size (layout, &text_width, NULL);
+	g_object_unref (layout);
+
+	return text_width + edge_width + indicator_width;
 }
 
 /* fill the canvas buffer with a tiled pixmap */
@@ -1219,7 +1215,7 @@ draw_or_layout_all_tabs (NautilusSidebarTabs *sidebar_tabs, gboolean layout_only
 							     GDK_RGB_DITHER_MAX,
 							     0, 0);
 
-			gdk_pixbuf_unref (tab_pixbuf);
+			g_object_unref (tab_pixbuf);
 		}
 	}
 	
@@ -1302,7 +1298,7 @@ nautilus_sidebar_tabs_expose (GtkWidget *widget, GdkEventExpose *event)
 							     GDK_RGB_DITHER_MAX,
 							     0, 0);
 					
-			gdk_pixbuf_unref (pixbuf); 
+			g_object_unref (pixbuf); 
 		} else {
 			draw_one_tab_plain (sidebar_tabs, temp_gc, sidebar_tabs->details->title, NULL,
 					    x_pos + TITLE_TAB_OFFSET, y_pos, sidebar_tabs->details->title_prelit, &sidebar_tabs->details->title_rect);
@@ -1350,13 +1346,13 @@ nautilus_sidebar_tabs_update_tab_item (NautilusSidebarTabs *sidebar_tabs, TabIte
 		tab_item->indicator_pixbuf_name = g_strdup (tab_image_name);	
 
 		if (tab_item->indicator_pixbuf != NULL) {
-			gdk_pixbuf_unref (tab_item->indicator_pixbuf);
+			g_object_unref (tab_item->indicator_pixbuf);
 			tab_item->indicator_pixbuf = NULL;	
 		}
 		if (tab_image_name != NULL) {
 			image_path = nautilus_theme_get_image_path (tab_image_name);
 			if (image_path != NULL) {
-				tab_item->indicator_pixbuf = gdk_pixbuf_new_from_file (image_path);	
+				tab_item->indicator_pixbuf = gdk_pixbuf_new_from_file (image_path, NULL);	
 				g_free (image_path);
 			}
 		}
@@ -1414,8 +1410,8 @@ nautilus_sidebar_tabs_update_indicator (NautilusSidebarTabs *sidebar_tabs, GtkWi
 
 static void
 tab_indicator_changed_callback (BonoboListener *listener,
-				char *event_name,
-				CORBA_any *arg,
+				const char *event_name,
+				const CORBA_any *arg,
 				CORBA_Environment *ev,
 				gpointer callback_data)
 {
@@ -1439,9 +1435,10 @@ nautilus_sidebar_tabs_connect_view (NautilusSidebarTabs *sidebar_tabs, GtkWidget
 	
 	property_bag = get_property_bag (tab_item);
 	if (property_bag != CORBA_OBJECT_NIL) {
-		tab_item->listener_id = bonobo_event_source_client_add_listener
-			(property_bag, tab_indicator_changed_callback, 
-			 "Bonobo/Property:change:tab_image", NULL, sidebar_tabs); 
+		tab_item->listener = bonobo_event_source_client_add_listener_full
+			(property_bag,
+			 g_cclosure_new (G_CALLBACK (tab_indicator_changed_callback), sidebar_tabs, NULL), 
+			 "Bonobo/Property:change:tab_image", NULL); 
 		bonobo_object_release_unref (property_bag, NULL);
 	}
 
@@ -1469,7 +1466,6 @@ nautilus_sidebar_tabs_add_view (NautilusSidebarTabs *sidebar_tabs, const char *n
 	new_tab_item = g_new0 (TabItem, 1);
 	new_tab_item->tab_text = g_strdup (name);
 	new_tab_item->visible = TRUE;
-	new_tab_item->prelit = FALSE;
 	new_tab_item->tab_view = new_view;
 	new_tab_item->notebook_page = page_num;
 
@@ -1645,7 +1641,7 @@ nautilus_sidebar_tabs_receive_dropped_color (NautilusSidebarTabs *sidebar_tabs,
 	}
 	
 	channels = (guint16 *) selection_data->data;
-	color_spec = g_strdup_printf ("rgb:%04hX/%04hX/%04hX", channels[0], channels[1], channels[2]);
+	color_spec = g_strdup_printf ("#%02X%02X%02X", channels[0] >> 8, channels[1] >> 8, channels[2] >> 8);
 	nautilus_sidebar_tabs_set_color(sidebar_tabs, color_spec);
 	g_free (color_spec);
 }
