@@ -30,7 +30,6 @@
 #include <config.h>
 #include "nautilus-sidebar.h"
 
-#include "nautilus-link-set-window.h"
 #include "nautilus-sidebar-tabs.h"
 #include "nautilus-sidebar-title.h"
 
@@ -51,6 +50,7 @@
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtknotebook.h>
+#include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-application-registry.h>
@@ -83,7 +83,7 @@ struct NautilusSidebarDetails {
 	gboolean has_buttons;
 	char *uri;
 	NautilusFile *file;
-	guint file_changed_connection;
+	gulong file_changed_connection;
 	char *default_background_color;
 	char *default_background_image;
 	int selected_index;
@@ -94,8 +94,8 @@ struct NautilusSidebarDetails {
 /* button assignments */
 #define CONTEXTUAL_MENU_BUTTON 3
 
-static void     nautilus_sidebar_initialize_class      (GtkObjectClass   *object_klass);
-static void     nautilus_sidebar_initialize            (GtkObject        *object);
+static void     nautilus_sidebar_class_init      (GtkObjectClass   *object_klass);
+static void     nautilus_sidebar_init            (GtkObject        *object);
 static void     nautilus_sidebar_deactivate_panel      (NautilusSidebar  *sidebar);
 static gboolean nautilus_sidebar_press_event           (GtkWidget        *widget,
 							GdkEventButton   *event);
@@ -106,6 +106,7 @@ static gboolean nautilus_sidebar_leave_event           (GtkWidget        *widget
 static gboolean nautilus_sidebar_motion_event          (GtkWidget        *widget,
 							GdkEventMotion   *event);
 static void     nautilus_sidebar_destroy               (GtkObject        *object);
+static void     nautilus_sidebar_finalize              (GObject          *object);
 static void     nautilus_sidebar_drag_data_received    (GtkWidget        *widget,
 							GdkDragContext   *context,
 							int               x,
@@ -125,7 +126,7 @@ static void     add_command_buttons                    (NautilusSidebar  *sideba
 							GList            *application_list);
 static void     background_metadata_changed_callback   (NautilusSidebar  *sidebar);
 
-#define DEFAULT_TAB_COLOR "rgb:9999/9999/9999"
+#define DEFAULT_TAB_COLOR "#999999"
 
 /* FIXME bugzilla.gnome.org 41245: hardwired sizes */
 #define SIDEBAR_MINIMUM_WIDTH 1
@@ -169,21 +170,25 @@ typedef enum {
 static gboolean confirm_trash_auto_value;
 
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusSidebar, nautilus_sidebar, GTK_TYPE_EVENT_BOX)
+EEL_CLASS_BOILERPLATE (NautilusSidebar, nautilus_sidebar, GTK_TYPE_EVENT_BOX)
 
 /* initializing the class object by installing the operations we override */
 static void
-nautilus_sidebar_initialize_class (GtkObjectClass *object_klass)
+nautilus_sidebar_class_init (GtkObjectClass *object_klass)
 {
 	GtkWidgetClass *widget_class;
+	GObjectClass *gobject_class;
 	
 	NautilusSidebarClass *klass;
 
 	widget_class = GTK_WIDGET_CLASS (object_klass);
 	klass = NAUTILUS_SIDEBAR_CLASS (object_klass);
+	gobject_class = G_OBJECT_CLASS (object_klass);
+	
+	gobject_class->finalize = nautilus_sidebar_finalize;
 
 	object_klass->destroy = nautilus_sidebar_destroy;
-
+	
 	widget_class->drag_data_received  = nautilus_sidebar_drag_data_received;
 	widget_class->motion_notify_event = nautilus_sidebar_motion_event;
 	widget_class->leave_notify_event = nautilus_sidebar_leave_event;
@@ -193,16 +198,15 @@ nautilus_sidebar_initialize_class (GtkObjectClass *object_klass)
 	widget_class->realize = nautilus_sidebar_realize;
 
 	/* add the "location changed" signal */
-	signals[LOCATION_CHANGED] = gtk_signal_new
+	signals[LOCATION_CHANGED] = g_signal_new
 		("location_changed",
-		 GTK_RUN_LAST,
-		 object_klass->type,
-		 GTK_SIGNAL_OFFSET (NautilusSidebarClass,
+		 G_TYPE_FROM_CLASS (object_klass),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET (NautilusSidebarClass,
 				    location_changed),
-		 gtk_marshal_NONE__STRING,
-		 GTK_TYPE_NONE, 1, GTK_TYPE_STRING);
-
-	gtk_object_class_add_signals (object_klass, signals, LAST_SIGNAL);
+		 NULL, NULL,
+		 g_cclosure_marshal_VOID__STRING,
+		 G_TYPE_NONE, 1, G_TYPE_STRING);
 
 	eel_preferences_add_auto_boolean (NAUTILUS_PREFERENCES_CONFIRM_TRASH,
 					       &confirm_trash_auto_value);
@@ -228,7 +232,7 @@ make_button_box (NautilusSidebar *sidebar)
 /* initialize the instance's fields, create the necessary subviews, etc. */
 
 static void
-nautilus_sidebar_initialize (GtkObject *object)
+nautilus_sidebar_init (GtkObject *object)
 {
 	NautilusSidebar *sidebar;
 	GtkWidget* widget;
@@ -267,6 +271,9 @@ nautilus_sidebar_initialize (GtkObject *object)
 
 	/* also, allocate the title tab */
 	sidebar->details->title_tab = NAUTILUS_SIDEBAR_TABS (nautilus_sidebar_tabs_new ());
+	g_object_ref (sidebar->details->title_tab);
+	gtk_object_sink (GTK_OBJECT (sidebar->details->title_tab));
+
 	nautilus_sidebar_tabs_set_title_mode (sidebar->details->title_tab, TRUE);	
 	
 	gtk_widget_show (GTK_WIDGET (sidebar->details->sidebar_tabs));
@@ -278,7 +285,7 @@ nautilus_sidebar_initialize (GtkObject *object)
 	
 	/* allocate and install the panel tabs */
   	sidebar->details->notebook = GTK_NOTEBOOK (gtk_notebook_new ());
-	gtk_object_ref (GTK_OBJECT (sidebar->details->notebook));
+	g_object_ref (sidebar->details->notebook);
 	gtk_object_sink (GTK_OBJECT (sidebar->details->notebook));
 		
 	gtk_notebook_set_show_tabs (sidebar->details->notebook, FALSE);
@@ -295,7 +302,7 @@ nautilus_sidebar_initialize (GtkObject *object)
 	/* prepare ourselves to receive dropped objects */
 	gtk_drag_dest_set (GTK_WIDGET (sidebar),
 			   GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP, 
-			   target_table, EEL_N_ELEMENTS (target_table),
+			   target_table, G_N_ELEMENTS (target_table),
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
 }
 
@@ -306,33 +313,47 @@ nautilus_sidebar_destroy (GtkObject *object)
 
 	sidebar = NAUTILUS_SIDEBAR (object);
 
-	gtk_object_unref (GTK_OBJECT (sidebar->details->notebook));
+	if (sidebar->details->notebook != NULL) {
+		g_object_unref (sidebar->details->notebook);
+		sidebar->details->notebook = NULL;
+	}
+	if (sidebar->details->title_tab != NULL) {
+		g_object_unref (sidebar->details->title_tab);
+		sidebar->details->title_tab = NULL;
+	}
+	
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+}
+
+static void
+nautilus_sidebar_finalize (GObject *object)
+{
+	NautilusSidebar *sidebar;
+
+	sidebar = NAUTILUS_SIDEBAR (object);
 
 	if (sidebar->details->file != NULL) {
-		gtk_signal_disconnect (GTK_OBJECT (sidebar->details->file), 
-				       sidebar->details->file_changed_connection);
+		g_signal_handler_disconnect (sidebar->details->file, 
+					     sidebar->details->file_changed_connection);
 		nautilus_file_monitor_remove (sidebar->details->file, sidebar);
 		nautilus_file_unref (sidebar->details->file);
 	}
-
-	gtk_object_sink (GTK_OBJECT (sidebar->details->title_tab));
 	
 	g_free (sidebar->details->uri);
 	g_free (sidebar->details->default_background_color);
 	g_free (sidebar->details->default_background_image);
-	
 	g_free (sidebar->details);
-	
+		
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME,
-					      nautilus_sidebar_theme_changed,
-					      sidebar);
+					 nautilus_sidebar_theme_changed,
+					 sidebar);
 
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_CONFIRM_TRASH,
-					      nautilus_sidebar_confirm_trash_changed,
-					      sidebar);
+					 nautilus_sidebar_confirm_trash_changed,
+					 sidebar);
 
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /* callback to handle resetting the background */
@@ -417,9 +438,9 @@ toggle_sidebar_panel (GtkWidget *widget,
 
 	g_return_if_fail (GTK_IS_CHECK_MENU_ITEM (widget));
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (widget))));
-	g_return_if_fail (gtk_object_get_data (GTK_OBJECT (widget), "nautilus-sidebar/preference-key") != NULL);
+	g_return_if_fail (g_object_get_data (G_OBJECT (widget), "nautilus-sidebar/preference-key") != NULL);
 
-	preference_key = gtk_object_get_data (GTK_OBJECT (widget), "nautilus-sidebar/preference-key");
+	preference_key = g_object_get_data (G_OBJECT (widget), "nautilus-sidebar/preference-key");
 
 	sidebar = NAUTILUS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (widget)));
 
@@ -482,17 +503,17 @@ sidebar_for_each_sidebar_panel (const char *name,
 	gtk_menu_append (data->menu, menu_item);
 	gtk_signal_connect_full (GTK_OBJECT (menu_item),
 				 "activate",
-				 GTK_SIGNAL_FUNC (toggle_sidebar_panel),
+				 G_CALLBACK (toggle_sidebar_panel),
 				 NULL,
 				 g_strdup (iid),
 				 g_free,
 				 FALSE,
 				 FALSE);
 
-	gtk_object_set_data_full (GTK_OBJECT (menu_item),
-				  "nautilus-sidebar/preference-key",
-				  g_strdup (preference_key),
-				  g_free);
+	g_object_set_data_full (G_OBJECT (menu_item),
+				"nautilus-sidebar/preference-key",
+				g_strdup (preference_key),
+				g_free);
 }
 
 /* utility routine to add a menu item for each potential sidebar panel */
@@ -547,7 +568,8 @@ nautilus_sidebar_create_context_menu (NautilusSidebar *sidebar)
  	gtk_widget_show (menu_item);
 	gtk_menu_append (GTK_MENU(menu), menu_item);
         gtk_widget_set_sensitive (menu_item, has_background);
-	gtk_signal_connect (GTK_OBJECT (menu_item), "activate", reset_background_callback, sidebar);
+	g_signal_connect (menu_item, "activate",
+			    G_CALLBACK (reset_background_callback), sidebar);
 
 	/* add a separator */
 	menu_item = gtk_menu_item_new ();
@@ -676,13 +698,13 @@ uri_is_local_image (const char *uri)
 		return FALSE;
 	}
 
-	pixbuf = gdk_pixbuf_new_from_file (image_path);
+	pixbuf = gdk_pixbuf_new_from_file (image_path, NULL);
 	g_free (image_path);
 	
 	if (pixbuf == NULL) {
 		return FALSE;
 	}
-	gdk_pixbuf_unref (pixbuf);
+	g_object_unref (pixbuf);
 	return TRUE;
 }
 
@@ -710,8 +732,8 @@ receive_dropped_uri_list (NautilusSidebar *sidebar,
 				(eel_get_widget_background (GTK_WIDGET (sidebar)),
 				 uris[0]);
 		} else if (exactly_one) {
-			gtk_signal_emit (GTK_OBJECT (sidebar),
-					 signals[LOCATION_CHANGED],
+			g_signal_emit (sidebar,
+					 signals[LOCATION_CHANGED], 0,
 			 		 uris[0]);	
 		}
 		break;
@@ -777,7 +799,7 @@ receive_dropped_color (NautilusSidebar *sidebar,
 	}
 	
 	channels = (guint16 *) selection_data->data;
-	color_spec = g_strdup_printf ("rgb:%04hX/%04hX/%04hX", channels[0], channels[1], channels[2]);
+	color_spec = g_strdup_printf ("#%02X%02X%02X", channels[0] >> 8, channels[1] >> 8, channels[2] >> 8);
 
 	switch (hit_test (sidebar, x, y)) {
 	case NO_PART:
@@ -792,7 +814,7 @@ receive_dropped_color (NautilusSidebar *sidebar,
 		/* Block so we don't respond to our own metadata changes.
 		 */
 		gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-						  background_metadata_changed_callback,
+						  G_CALLBACK (background_metadata_changed_callback),
 						  sidebar);
 						  
 		nautilus_file_set_metadata
@@ -802,7 +824,7 @@ receive_dropped_color (NautilusSidebar *sidebar,
 			 color_spec);
 
 		gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-						    background_metadata_changed_callback,
+						    G_CALLBACK (background_metadata_changed_callback),
 						    sidebar);
 		break;
 	case TITLE_TAB_PART:
@@ -814,7 +836,7 @@ receive_dropped_color (NautilusSidebar *sidebar,
 		/* Block so we don't respond to our own metadata changes.
 		 */
 		gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-						  background_metadata_changed_callback,
+						  G_CALLBACK (background_metadata_changed_callback),
 						  sidebar);
 
 		nautilus_file_set_metadata
@@ -824,7 +846,7 @@ receive_dropped_color (NautilusSidebar *sidebar,
 			 color_spec);
 
 		gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-						    background_metadata_changed_callback,
+						    G_CALLBACK (background_metadata_changed_callback),
 						    sidebar);
 		break;
 	case ICON_PART:
@@ -916,7 +938,8 @@ nautilus_sidebar_add_panel (NautilusSidebar *sidebar, NautilusViewFrame *panel)
 
 	gtk_widget_show (label);
 	
-	gtk_signal_connect (GTK_OBJECT (panel), "view_loaded", view_loaded_callback, sidebar);
+	g_signal_connect (panel, "view_loaded",
+			    G_CALLBACK (view_loaded_callback), sidebar);
 	
 	gtk_notebook_append_page (GTK_NOTEBOOK (sidebar->details->notebook),
 				  GTK_WIDGET (panel), label);
@@ -1190,7 +1213,7 @@ background_settings_changed_callback (EelBackground *background, NautilusSidebar
 	/* Block so we don't respond to our own metadata changes.
 	 */
 	gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-					  background_metadata_changed_callback,
+					  G_CALLBACK (background_metadata_changed_callback),
 					  sidebar);
 
 	color = eel_background_get_color (background);
@@ -1210,7 +1233,7 @@ background_settings_changed_callback (EelBackground *background, NautilusSidebar
 	g_free (image);
 
 	gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-					    background_metadata_changed_callback,
+					    G_CALLBACK (background_metadata_changed_callback),
 					    sidebar);
 }
 
@@ -1229,7 +1252,7 @@ background_reset_callback (EelBackground *background, NautilusSidebar *sidebar)
 	/* Block so we don't respond to our own metadata changes.
 	 */
 	gtk_signal_handler_block_by_func (GTK_OBJECT (sidebar->details->file),
-					  background_metadata_changed_callback,
+					  G_CALLBACK (background_metadata_changed_callback),
 					  sidebar);
 
 	nautilus_file_set_metadata (sidebar->details->file,
@@ -1243,7 +1266,7 @@ background_reset_callback (EelBackground *background, NautilusSidebar *sidebar)
 				    NULL);
 
 	gtk_signal_handler_unblock_by_func (GTK_OBJECT (sidebar->details->file),
-					    background_metadata_changed_callback,
+					    G_CALLBACK (background_metadata_changed_callback),
 					    sidebar);
 
 	/* Force a read from the metadata to set the defaults
@@ -1281,23 +1304,13 @@ command_button_callback (GtkWidget *button, char *id_str)
 
 /* interpret commands for buttons specified by metadata. Handle some built-in ones explicitly, or fork
    a shell to handle general ones */
-/* for now, we only handle a few built in commands */
+/* for now, we don't have any of these */
 static void
 metadata_button_callback (GtkWidget *button, const char *command_str)
 {
-	GtkWindow *window;
 	NautilusSidebar *sidebar;
-	char *path;
-	
+		
 	sidebar = NAUTILUS_SIDEBAR (gtk_object_get_user_data (GTK_OBJECT (button)));
-	if (strcmp (command_str, "#linksets") == 0) {
-		window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (sidebar)));
-		path = gnome_vfs_get_local_path_from_uri (sidebar->details->uri);
-		if (path != NULL) {
-			nautilus_link_set_toggle_configure_window (path, window);
-			g_free (path);
-		}
-	}
 }
 
 static void
@@ -1369,14 +1382,14 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 			file_path = g_strdup (sidebar->details->uri);
 		} 
 
-		temp_str = eel_shell_quote (file_path);		
+		temp_str = g_shell_quote (file_path);		
 		id_string = g_strdup_printf (application->id, temp_str); 		
 		g_free (file_path);
 		g_free (temp_str);
 
 		eel_gtk_signal_connect_free_data 
 			(GTK_OBJECT (temp_button), "clicked",
-			 GTK_SIGNAL_FUNC (command_button_callback), id_string);
+			 G_CALLBACK (command_button_callback), id_string);
 
                 gtk_object_set_user_data (GTK_OBJECT (temp_button), sidebar);
 		
@@ -1385,8 +1398,8 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 
 	/* Catch-all button after all the others. */
 	temp_button = gtk_button_new_with_label (_("Open with..."));
-	gtk_signal_connect (GTK_OBJECT (temp_button), "clicked",
-			    open_with_callback, NULL);
+	g_signal_connect (temp_button, "clicked",
+			    G_CALLBACK (open_with_callback), NULL);
 	gtk_object_set_user_data (GTK_OBJECT (temp_button), sidebar);
 	gtk_widget_show (temp_button);
 	gtk_box_pack_start (GTK_BOX (sidebar->details->button_box),
@@ -1411,13 +1424,13 @@ add_buttons_from_metadata (NautilusSidebar *sidebar, const char *button_data)
 	
 	/* for each term, either create a button or attach a property to one */
 	for (index = 0; (term = terms[index]) != NULL; index++) {
-		current_term = g_strdup(term);
-		temp_str = strchr(current_term, '=');
+		current_term = g_strdup (term);
+		temp_str = strchr (current_term, '=');
 		if (temp_str) {
 			*temp_str = '\0';
-			if (!g_strcasecmp(current_term, "button")) {
-				button_name = g_strdup(temp_str + 1);
-			} else if (!g_strcasecmp(current_term, "script")) {
+			if (!g_ascii_strcasecmp (current_term, "button")) {
+				button_name = g_strdup (temp_str + 1);
+			} else if (!g_ascii_strcasecmp (current_term, "script")) {
 			        if (button_name != NULL) {
 			        	temp_button = gtk_button_new_with_label (button_name);		    
 					gtk_box_pack_start (GTK_BOX (sidebar->details->button_box), 
@@ -1430,7 +1443,7 @@ add_buttons_from_metadata (NautilusSidebar *sidebar, const char *button_data)
 					
 					eel_gtk_signal_connect_free_data 
 						(GTK_OBJECT (temp_button), "clicked",
-						 GTK_SIGNAL_FUNC (metadata_button_callback), command_string);
+						 G_CALLBACK (metadata_button_callback), command_string);
 		                	gtk_object_set_user_data (GTK_OBJECT (temp_button), sidebar);
 					
 					gtk_widget_show (temp_button);			
@@ -1491,25 +1504,21 @@ nautilus_sidebar_update_buttons (NautilusSidebar *sidebar)
 	 * need a framework to allow protocols to add commands buttons */
 	if (eel_istr_has_prefix (sidebar->details->uri, "trash:")) {
 		/* FIXME: We don't use spaces to pad labels! */
-		temp_button = gtk_button_new_with_label (confirm_trash_auto_value 
-							 ? _("Empty Trash...") 
-							 : _("Empty Trash"));
-		eel_gtk_button_set_standard_padding (GTK_BUTTON (temp_button));
+		temp_button = gtk_button_new_with_mnemonic (confirm_trash_auto_value 
+							 ? _("_Empty Trash...") 
+							 : _("_Empty Trash"));
+
 		gtk_box_pack_start (GTK_BOX (sidebar->details->button_box), 
 					temp_button, FALSE, FALSE, 0);
 		gtk_widget_set_sensitive (temp_button, !nautilus_trash_monitor_is_empty ());
 		gtk_widget_show (temp_button);
 		sidebar->details->has_buttons = TRUE;
 					
-		gtk_signal_connect (GTK_OBJECT (temp_button), "clicked",
-			GTK_SIGNAL_FUNC (empty_trash_callback), NULL);
+		g_signal_connect (temp_button, "clicked",
+				  G_CALLBACK (empty_trash_callback), NULL);
 		
-		gtk_signal_connect_while_alive (GTK_OBJECT (nautilus_trash_monitor_get ()),
-				        "trash_state_changed",
-				        nautilus_sidebar_trash_state_changed_callback,
-				        temp_button,
-				        GTK_OBJECT (temp_button));
-
+		g_signal_connect_object (nautilus_trash_monitor_get (), "trash_state_changed",
+					 G_CALLBACK (nautilus_sidebar_trash_state_changed_callback), temp_button, 0);
 	}
 	
 	/* Make buttons for each item in short list + "Open with..." catchall,
@@ -1546,13 +1555,13 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 	background = eel_get_widget_background (GTK_WIDGET (sidebar));
 	if (!sidebar->details->background_connected) {
 		sidebar->details->background_connected = TRUE;
-		gtk_signal_connect (GTK_OBJECT (background),
+		g_signal_connect (background,
 				    "settings_changed",
-				    background_settings_changed_callback,
+				    G_CALLBACK (background_settings_changed_callback),
 				    sidebar);
-		gtk_signal_connect (GTK_OBJECT (background),
+		g_signal_connect (background,
 				    "reset",
-				    background_reset_callback,
+				    G_CALLBACK (background_reset_callback),
 				    sidebar);
 	}
 	
@@ -1572,7 +1581,7 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 		
 	/* Block so we don't write these settings out in response to our set calls below */
 	gtk_signal_handler_block_by_func (GTK_OBJECT (background),
-					  background_settings_changed_callback,
+					  G_CALLBACK (background_settings_changed_callback),
 					  sidebar);
 
 	eel_background_set_image_uri (background, background_image);
@@ -1594,7 +1603,7 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 	g_free (color_spec);
 
 	gtk_signal_handler_unblock_by_func (GTK_OBJECT (background),
-					    background_settings_changed_callback,
+					    G_CALLBACK (background_settings_changed_callback),
 					    sidebar);
 }
 
@@ -1640,8 +1649,8 @@ nautilus_sidebar_set_uri (NautilusSidebar *sidebar,
 	sidebar->details->uri = g_strdup (new_uri);
 		
 	if (sidebar->details->file != NULL) {
-		gtk_signal_disconnect (GTK_OBJECT (sidebar->details->file), 
-				       sidebar->details->file_changed_connection);
+		g_signal_handler_disconnect (sidebar->details->file, 
+					     sidebar->details->file_changed_connection);
 
 		nautilus_file_monitor_remove (sidebar->details->file, sidebar);
 	}
@@ -1656,7 +1665,7 @@ nautilus_sidebar_set_uri (NautilusSidebar *sidebar,
 	sidebar->details->file_changed_connection =
 		gtk_signal_connect_object (GTK_OBJECT (sidebar->details->file),
 					   "changed",
-					   background_metadata_changed_callback,
+					   G_CALLBACK (background_metadata_changed_callback),
 					   GTK_OBJECT (sidebar));
 
 	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
