@@ -39,7 +39,6 @@
 #include <bonobo/bonobo-control-frame.h>
 #include <bonobo/bonobo-zoomable-frame.h>
 #include <bonobo/bonobo-zoomable.h>
-#include <eel/eel-gobject-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-marshal.h>
@@ -152,14 +151,10 @@ nautilus_view_frame_init (NautilusViewFrame *view)
 
 	view->details->idle_queue = nautilus_idle_queue_new ();
 
-	eel_signal_connect_object_while_alive (G_OBJECT (nautilus_signaller_get_current ()),
-					       "history_list_changed",
-					       G_CALLBACK (send_history),
-					       G_OBJECT (view));
-	eel_signal_connect_object_while_alive (G_OBJECT (nautilus_icon_factory_get ()),
-					       "icons_changed",
-					       G_CALLBACK (send_history),
-					       G_OBJECT (view));
+	g_signal_connect_object (nautilus_signaller_get_current (), "history_list_changed",
+				 G_CALLBACK (send_history), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (send_history), view, G_CONNECT_SWAPPED);
 }
 
 static void
@@ -733,42 +728,22 @@ attach_view (NautilusViewFrame *view,
 
 	widget = bonobo_control_frame_get_widget (view->details->control_frame);
 
-	eel_signal_connect_object_while_alive
-		(G_OBJECT (view->details->view_frame),
-		 "destroy",
-		 G_CALLBACK (view_frame_failed), G_OBJECT (view));
-	eel_signal_connect_object_while_alive
-		(G_OBJECT (view->details->view_frame),
-		 "system_exception",
-		 G_CALLBACK (queue_view_frame_failed), G_OBJECT (view));
-
-	eel_signal_connect_object_while_alive
-		(G_OBJECT (view->details->control_frame),
-		 "system_exception",
-		 G_CALLBACK (queue_view_frame_failed), G_OBJECT (view));
-
-	eel_signal_connect_while_alive
-		(G_OBJECT (widget),
-		 "remove",
-		 G_CALLBACK (check_socket_gone_callback), view,
-		 G_OBJECT (view));
+	g_signal_connect_object	(view->details->view_frame, "destroy",
+				 G_CALLBACK (view_frame_failed), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object	(view->details->view_frame, "system_exception",
+				 G_CALLBACK (queue_view_frame_failed), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object	(view->details->control_frame, "system_exception",
+				 G_CALLBACK (queue_view_frame_failed), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object	(widget, "remove",
+				 G_CALLBACK (check_socket_gone_callback), view, 0);
 
 	if (view->details->zoomable_frame != NULL) {
-		eel_signal_connect_object_while_alive
-			(G_OBJECT (view->details->zoomable_frame),
-			 "system_exception",
-			 G_CALLBACK (queue_view_frame_failed), G_OBJECT (view));
-
-		eel_signal_connect_while_alive
-			(G_OBJECT (view->details->zoomable_frame),
-			 "zoom_parameters_changed",
-			 G_CALLBACK (zoom_parameters_changed_callback), view,
-			 G_OBJECT (view));
-		eel_signal_connect_while_alive
-			(G_OBJECT (view->details->zoomable_frame),
-			 "zoom_level_changed",
-			 G_CALLBACK (zoom_level_changed_callback), view,
-			 G_OBJECT (view));
+		g_signal_connect_object	(view->details->zoomable_frame, "system_exception",
+					 G_CALLBACK (queue_view_frame_failed), view, G_CONNECT_SWAPPED);
+		g_signal_connect_object (view->details->zoomable_frame, "zoom_parameters_changed",
+					 G_CALLBACK (zoom_parameters_changed_callback), view, 0);
+		g_signal_connect_object (view->details->zoomable_frame, "zoom_level_changed",
+					 G_CALLBACK (zoom_level_changed_callback), view, 0);
 	}
 
 	gtk_widget_show (widget);
