@@ -641,7 +641,7 @@ help_menu_about_nautilus_callback (BonoboUIComponent *component,
 		g_free (build_message);
 	}
 	
-	eel_gtk_window_present (GTK_WINDOW (about));
+	gtk_window_present (GTK_WINDOW (about));
 }
 
 static void
@@ -971,7 +971,7 @@ get_bookmark_list (void)
 {
         if (bookmarks == NULL) {
                 bookmarks = nautilus_bookmark_list_new ();
-		g_atexit (free_bookmark_list);
+		eel_debug_call_at_shutdown (free_bookmark_list);
         }
 
         return bookmarks;
@@ -1017,7 +1017,7 @@ add_bookmark_for_current_location (NautilusWindow *window)
 static void
 edit_bookmarks (NautilusWindow *window)
 {
-        eel_gtk_window_present
+        gtk_window_present
 		(get_or_create_bookmarks_window (G_OBJECT (window)));
 }
 
@@ -1069,16 +1069,12 @@ nautilus_window_initialize_bookmarks_menu (NautilusWindow *window)
 						  G_OBJECT (window));
 		
 	/* Recreate dynamic part of menu if bookmark list changes */
-	gtk_signal_connect_object_while_alive (GTK_OBJECT (get_bookmark_list ()),
-			                       "contents_changed",
-			                       G_CALLBACK (schedule_refresh_bookmarks_menu),
-			   	               GTK_OBJECT (window));
+	g_signal_connect_object (get_bookmark_list (), "contents_changed",
+				 G_CALLBACK (schedule_refresh_bookmarks_menu), window, G_CONNECT_SWAPPED);
 
 	/* Recreate static & dynamic parts of menu if icon theme changes */
-	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (),
-					       "icons_changed",
-					       G_CALLBACK (schedule_refresh_bookmarks_menu),
-					       GTK_OBJECT (window));
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (schedule_refresh_bookmarks_menu), window, G_CONNECT_SWAPPED);
 }
 
 /**
@@ -1092,15 +1088,10 @@ nautilus_window_initialize_go_menu (NautilusWindow *window)
 	/* Recreate bookmarks part of menu if history list changes
 	 * or if icon theme changes.
 	 */
-	gtk_signal_connect_object_while_alive (nautilus_signaller_get_current (),
-			                       "history_list_changed",
-			                       G_CALLBACK (schedule_refresh_go_menu),
-			   	               GTK_OBJECT (window));
-	 
-	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (),
-					       "icons_changed",
-					       G_CALLBACK (schedule_refresh_go_menu),
-					       GTK_OBJECT (window));
+	g_signal_connect_object (nautilus_signaller_get_current (), "history_list_changed",
+				 G_CALLBACK (schedule_refresh_go_menu), window, G_CONNECT_SWAPPED);
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (schedule_refresh_go_menu), window, G_CONNECT_SWAPPED);
 }
 
 /**
